@@ -1,18 +1,19 @@
 use strict;
 use warnings;
 package Dist::Zilla::Plugin::CheckBin;
-BEGIN {
-  $Dist::Zilla::Plugin::CheckBin::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v0.001-1-gba10836
-$Dist::Zilla::Plugin::CheckBin::VERSION = '0.002';
+# git description: v0.002-20-ge7f4174
+$Dist::Zilla::Plugin::CheckBin::VERSION = '0.003';
 # ABSTRACT: Require that our distribution has a particular command available
+# KEYWORDS: distribution installation require binary program executable
 # vim: set ts=8 sw=4 tw=78 et :
 
 use Moose;
-with 'Dist::Zilla::Role::InstallTool',
+with
+    'Dist::Zilla::Role::FileMunger',
+    'Dist::Zilla::Role::InstallTool',
     'Dist::Zilla::Role::PrereqSource',
 ;
+use Scalar::Util 'blessed';
 use namespace::autoclean;
 
 sub mvp_multivalue_args { 'command' }
@@ -22,10 +23,23 @@ has command => (
     lazy => 1,
     default => sub { [] },
     traits => ['Array'],
-    handles => { command => 'elements' },
+    handles => { command => 'sort' },   # sorted elements
 );
 
-sub register_prereqs {
+around dump_config => sub
+{
+    my ($orig, $self) = @_;
+    my $config = $self->$orig;
+
+    $config->{+__PACKAGE__} = {
+        command => [ $self->command ],
+    };
+
+    return $config;
+};
+
+sub register_prereqs
+{
     my $self = shift;
     $self->zilla->register_prereqs(
         {
@@ -36,9 +50,25 @@ sub register_prereqs {
     );
 }
 
+my %files;
+sub munge_files
+{
+    my $self = shift;
+
+    my @mfpl = grep { $_->name eq 'Makefile.PL' or $_->name eq 'Build.PL' } @{ $self->zilla->files };
+    for my $mfpl (@mfpl)
+    {
+        $self->log_debug('munging ' . $mfpl->name . ' in file gatherer phase');
+        $files{$mfpl->name} = $mfpl;
+        $self->_munge_file($mfpl);
+    }
+    return;
+}
+
 # XXX - this should really be a separate phase that runs after InstallTool -
 # until then, all we can do is die if we are run too soon
-sub setup_installer {
+sub setup_installer
+{
     my $self = shift;
 
     my @mfpl = grep { $_->name eq 'Makefile.PL' or $_->name eq 'Build.PL' } @{ $self->zilla->files };
@@ -47,14 +77,36 @@ sub setup_installer {
 
     for my $mfpl (@mfpl)
     {
-        my $content = "use Devel::CheckBin;\n"
-            . join(' ', map { 'check_bin(\'' . $_ . "\');\n" } $self->command)
-            . "\n";
-        $mfpl->content($content . $mfpl->content);
+        next if exists $files{$mfpl->name};
+        $self->log_debug('munging ' . $mfpl->name . ' in setup_installer phase');
+        $self->_munge_file($mfpl);
     }
     return;
 }
 
+sub _munge_file
+{
+    my ($self, $file) = @_;
+
+    my $orig_content = $file->content;
+    $self->log_fatal('could not find position in ' . $file->name . ' to modify!')
+        if not $orig_content =~ m/use strict;\nuse warnings;\n\n/g;
+
+    my $pos = pos($orig_content);
+
+    my $content =
+        "# inserted by " . blessed($self) . ' ' . ($self->VERSION || '<self>') . "\n"
+        . "use Devel::CheckBin;\n"
+        . join('', map { 'check_bin(\'' . $_ . "\');\n" } $self->command)
+        . "\n";
+
+    $file->content(
+        substr($orig_content, 0, $pos)
+        . $content
+        . substr($orig_content, $pos)
+    );
+}
+
 __PACKAGE__->meta->make_immutable;
 
 __END__
@@ -63,19 +115,17 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords Karen Etheridge irc
-
 =head1 NAME
 
 Dist::Zilla::Plugin::CheckBin - Require that our distribution has a particular command available
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
-In your F<dist.ini>
+In your F<dist.ini>:
 
     [CheckBin]
     command = ls
@@ -88,9 +138,9 @@ L<Devel::CheckBin> call, that asserts that a particular command is available.
 If it is not available, the program exits with a status of zero, which on a
 L<CPAN Testers|cpantesters.org> machine will result in a NA result.
 
-=for Pod::Coverage mvp_multivalue_args register_prereqs setup_installer
+=for Pod::Coverage mvp_multivalue_args register_prereqs munge_files setup_installer
 
-=head1 CONFIGURATION
+=head1 CONFIGURATION OPTIONS
 
 =head2 C<command>
 
@@ -98,6 +148,8 @@ Identifies the name of the command that is searched for. Can be used more than o
 
 =head1 SUPPORT
 
+=for stopwords irc
+
 Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-CheckBin>
 (or L<bug-Dist-Zilla-Plugin-CheckBin@rt.cpan.org|mailto:bug-Dist-Zilla-Plugin-CheckBin@rt.cpan.org>).
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
@@ -114,6 +166,10 @@ L<Devel::CheckBin>
 
 L<Devel::AssertOS> and L<Dist::Zilla::Plugin::AssertOS>
 
+=item *
+
+L<Devel::CheckLib> and L<Dist::Zilla::Plugin::CheckLib>
+
 =back
 
 =head1 AUTHOR
